{% extends "horizon/common/_modal_form.html" %}
{% load i18n %}
{% block form_attrs %}enctype="multipart/form-data"{% endblock %}
{% block modal-body-right %}
  <h3>{% trans "Description:" %}</h3>
  <p>{% trans "Use one of the available definition source options to specify the definition to be used in creating this workflow." %}</p>
  <p>
    {% trans "Refer "%}
    <a href="https://docs.openstack.org/mistral/latest/api/v2.html#workflows" title="Workflow Language Syntax" target="_blank">
      Mistral Workflow Language</a>
    {% trans " documentation for syntax details." %}
  </p>
{% endblock %}
