{% extends "horizon/common/_modal_form.html" %}
{% load i18n %}

{% block form_id %}execute_form{% endblock %}
{% block form_action %}{% url 'horizon:mistral:workflows:execute' workflow_name %}{% endblock %}

{% block modal-header %}{% trans "Execute" %}{% endblock %}

{% block modal-body %}
<div class="left">
    <fieldset>
    {% include "horizon/common/_form_fields.html" %}
    </fieldset>
</div>
<div class="right">
    <h3>{% trans "Description:" %}</h3>
    <p>{% trans "From here you can execute a workflow." %}</p>
</div>
{% endblock %}
