{% extends 'mistral/default/base.html' %}
{% load i18n %}
{% block title %}{% trans "Execute workflow" %}{% endblock %}

{% block page_header %}
  {% include "horizon/common/_page_header.html" with title=_("Execute workflow") %}
{% endblock page_header %}

{% block main %}
  {% include 'mistral/workflows/_execute.html' %}
{% endblock %}
